@@ -48,6 +48,9 @@ SERVICE_VERSIONS = {
     "apigateway": [
         "2018-08-08"
     ],
+    "apm": [
+        "2021-06-22"
+    ],
     "asr": [
         "2019-06-14"
     ],
@@ -307,6 +310,9 @@ SERVICE_VERSIONS = {
     "iotvideoindustry": [
         "2020-12-01"
     ],
+    "ivld": [
+        "2021-09-03"
+    ],
     "kms": [
         "2019-01-18"
     ],
@@ -487,6 +493,9 @@ SERVICE_VERSIONS = {
         "2021-07-01",
         "2020-12-21"
     ],
+    "thpc": [
+        "2021-11-09"
+    ],
     "tia": [
         "2018-02-26"
     ],
